from __future__ import annotations

from .eng.Core17InstructionRetrieval import *
from .eng.News21InstructionRetrieval import *
from .eng.Robust04InstructionRetrieval import *
from .multilingual.mFollowIR import *
