from __future__ import annotations

from .aggregated_tasks import *
from .BitextMining import *
from .Classification import *
from .Clustering import *
from .Image.Any2AnyMultiChoice import *
from .Image.Any2AnyRetrieval import *
from .Image.Clustering import *
from .Image.ImageClassification import *
from .Image.ImageMultilabelClassification import *
from .Image.ImageTextPairClassification import *
from .Image.VisualSTS import *
from .Image.ZeroshotClassification import *
from .InstructionRetrieval import *
from .MultiLabelClassification import *
from .PairClassification import *
from .Reranking import *
from .Retrieval import *
from .SpeedTask import *
from .STS import *
from .Summarization import *
