from __future__ import annotations

from .eng.BirdsnapClassification import *
from .eng.Caltech101Classification import *
from .eng.CIFAR import *
from .eng.Country211Classification import *
from .eng.DTDClassification import *
from .eng.EuroSATClassification import *
from .eng.FER2013Classification import *
from .eng.FGVCAircraftClassification import *
from .eng.Food101Classification import *
from .eng.GTSRBClassification import *
from .eng.Imagenet1k import *
from .eng.MNISTClassification import *
from .eng.OxfordFlowersClassification import *
from .eng.OxfordPetsClassification import *
from .eng.PatchCamelyonClassification import *
from .eng.RESISC45Classification import *
from .eng.StanfordCarsClassification import *
from .eng.STL10Classification import *
from .eng.SUN397Classification import *
from .eng.UCF101Classification import *
